Powerbase: Los Angeles Event #1 Strategicon - GAMEX 2010, Los Angeles, California May 29th 2010 2R+F 12 players Darby Keeney Deck Name: [2010 TW] The World's Biggest Small Multirushers Comments: Many thanks to Fred Scott for lending me 2 Tupdogs for this tournament. Generally, I have found a 2.5:1 Tupdog-to-!Tremere ratio to work out pretty well, though a long string of Dogs at the top pf one's crypt is frustrating. The objective for this deck is to get additional mileage from the Tupdogs...decreasing their effective cost from 1 pool per action to 0.5 pool per action and further leveraging both the rush and the slave option (rush first, untap, available for slave clause, take an action of the slave clause is not needed). The deck is supposed to carry 1 more Ashur Tablet, but I seem to own only 5 at this time. 4, 6 or 7 seem like the right numbers to me, depending on your risk tolerance and recycling needs. Synergies: Carver's + Dragonbound and Carver's + Vessel are pretty clear. Carver's + Raw Recruit is an indefinate hold on a Recruit target (that could not be Graverobbed). Carver's not affecting Tupdogs is a bonus. Heidleburg can save master vampires from dangerous hunting requirements, can empty a Tupdog of before it explodes and allows 2 Hand of Conrad actions per turn. a "good" combat ran "set close and agg hands, grapple, prevent and untap" Crypt (18 cards, min=4, max=15, avg=1.72) ----------------------------------------- 13x Tupdog 1 POT VIS Gargoyle:3 1x Esoara 5 DOM aus for pot Tremere antitribu:4 1x Janine 4 aus dom tha Tremere antitribu:4 1x Ember Wright 3 aus dom Tremere antitribu:3 1x Keith Moody 3 DOM Tremere antitribu:4 1x Saiz 3 aus dom Tremere antitribu:3 Library (79 cards) Master (13; 2 trifle) 5x Ashur Tablets -- tune late-game combat as needed. 1x Carver's Meat Packing and Storage -- anti-weenie. 1x Dreams of the Sphinx -- combat support or free Tupdogs. 1x Fame 1x Heidelberg Castle, Germany 1x Powerbase: Montreal -- free Tupdogs 1x Secure Haven -- to contest and to save a slave master. 2x Vessel Action (13) 5x Dive Bomb -- stealth multi-rush as a "spare" Tupdog action 1x Goblinism -- destroy location as a "spare" Tupdog action. 2x Graverobbing 3x Raw Recruit -- additional slaves from a "spare" Tupdog action. 2x Thin-Blooded Seer -- Tupdog "spare" actions. Ally (1) 1x Nephandus -- safe removal of torporized minions. Equipment (2) 1x Hand of Conrad -- recycle Tupdogs, should probably be duplicated. 1x Sargon Fragment, The -- recycle everything else Political Action (2) 1x Ancient Influence -- eradicate your prey and call as a "spare" Tupdog action 1x Reins of Power -- eradicate your predator and call as a "spare" Tupdog action Action Modifier (8) 8x As the Crow -- makes my Tuppers freaky. Combat (39) 8x Brick by Brick 8x Immortal Grapple 4x Lead Fist -- critical to circumvent "prevent 1" decks 9x Raking Talons -- probably should be 10. 10x Stonestrength Event (1) 1x Dragonbound